# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`selinux`](#selinux): Manage active SELinux state and state after a reboot
* [`selinux::config`](#selinuxconfig): This class sets selinux system parameters
* [`selinux::install`](#selinuxinstall): Install selinux-related packages not managed by vox_selinux
* [`selinux::service`](#selinuxservice): Ensures mcstrans and restorecond services are running, as appropriate

**Resource types**

* [`selinux_login`](#selinux_login): Manage SELinux login mapping configuration  NOTE: You may need to run `restorecon -RF` on any user home directories that have their default c
* [`selinux_state`](#selinux_state): Toggle the enforcement of selinux

## Classes

### selinux

Manage active SELinux state and state after a reboot

#### Parameters

The following parameters are available in the `selinux` class.

##### `ensure`

Data type: `Selinux::State`

The state that SELinux should be in.
Since you are calling this class, we assume that you want to enforce.

Default value: 'enforcing'

##### `mode`

Data type: `Enum['targeted','mls']`

The SELinux type you want to enforce.
Note, it is quite possible that 'mls' will render your system inoperable.

Default value: 'targeted'

##### `autorelabel`

Data type: `Boolean`

Automatically relabel the filesystem if needed

Default value: `false`

##### `manage_utils_package`

Data type: `Boolean`

If true, ensure policycoreutils-python is installed. This is a supplemental
package that is required by semanage.

Default value: `true`

##### `manage_mcstrans_package`

Data type: `Boolean`

Manage the `mcstrans` package.

##### `manage_mcstrans_service`

Data type: `Boolean`

Manage the `mcstrans` service.

##### `mcstrans_service_name`

Data type: `String`

The `mcstrans` service name.

##### `mcstrans_package_name`

Data type: `String`

The `mcstrans` package name.

##### `manage_restorecond_package`

Data type: `Boolean`

Manage the `restorecond` package.

##### `manage_restorecond_service`

Data type: `Boolean`

Manage the `restorecond` service.

##### `restorecond_package_name`

Data type: `String`

The `restorecond` package name.

##### `package_ensure`

Data type: `String`

The ensure status of packages to be installed

Default value: simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })

##### `login_resources`

Data type: `Optional[Hash]`

A hash of resources that should be created on the system as expected by
`create_resources()` called on the `selinux_login` type

@example Change __default__ to user_u
  ---
  selinux::login_resources:
    "__default__":
      seuser: user_u
      mls_range: s0
    "%admins":
      seuser: staff_u
      mls_range: "SystemLow-SystemHigh"

Default value: `undef`

### selinux::config

This class sets selinux system parameters

### selinux::install

Install selinux-related packages not managed by vox_selinux

### selinux::service

Ensures mcstrans and restorecond services are running,
as appropriate

## Resource types

### selinux_login

Manage SELinux login mapping configuration

NOTE: You may need to run `restorecon -RF` on any user home directories that
have their default contexts updated. This is particularly important for the
`__default__` login entry but cannot be automated given the potential load
and unintended system consequences.

#### Properties

The following properties are available in the `selinux_login` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `seuser`

Valid values: /^.+$/

The SELinux user to which the login should be mapped.
You can get a list by running `semanage user -l`

##### `mls_range`

Valid values: /^.+$/

The Multi-Level Security range to be applied to the login

#### Parameters

The following parameters are available in the `selinux_login` type.

##### `name`

namevar

The user or group name to be managed. Groups must be prefixed with a "%"

##### `force`

Valid values: `true`, `false`, yes, no

Force the modification of potentially unsafe logins such as "root" and "__default__"

Default value: `false`

### selinux_state

Toggle the enforcement of selinux

#### Properties

The following properties are available in the `selinux_state` type.

##### `ensure`

Valid values: `false`, `true`, disabled, permissive, enforcing

Set the SELinux state on the system

Default value: enforcing

#### Parameters

The following parameters are available in the `selinux_state` type.

##### `name`

namevar

An arbitrary, but unique, name for the resource.

##### `autorelabel`

Valid values: `true`, `false`, yes, no

Automatically determine if the filesystem needs to be relabeled.
  Enforcing > Permissive > Disabled
Going to the right requires relabeling.

Default value: `true`

